.. _RKD: https://pypi.org/project/rkd
.. _documentation: https://riotkit-do.readthedocs.io/en/latest/standardlib/python.html
.. _here: https://riotkit-do.readthedocs.io/en/latest/standardlib/python.html

RKD Python
==========

Python packaging and development utilities.

**Why a separate package?** Some of dependencies like *Twine* require GCC/G++ and too many dependencies to be installed. 
RKD core needs to be enough lightweight so it could be used inside docker images without a noticeable footprint.


The documentation is placed in RKD documentation.
Unit tests are separated.

This is a component of RKD_
~~~~~~~~~~~~~~~~~~~~~~~~~~~

Check documentation_ here_
~~~~~~~~~~~~~~~~~~~~~~~~~~
